# frankensteins-qtile

Frankenstein's Qtile (frankentile for short) is a library to be used in the configuration of qtile. It is designed to have unnessesary with over the top features that are cool but ultimately mostly useless. It contains features like sending log messages to a discord server, an api to set the wallpaper, etc.
